# Jumbo API
Unofficial Python wrapper for the Jumbo API, a way to view your Jumbo deliveries
Use the same credentials as the ones you use for the app.

This library is not affiliated with Jumbo and retrieves data from the endpoints of the mobile application. Use at your own risk.

## Home Assistant
This library is being used in Home Assistant as a [custom component](https://github.com/peternijssen/home-asssistant-jumbo).

## Contributors
* [Peter Nijssen](https://github.com/peternijssen)
* [Rolf Berkenbosch](https://github.com/rolfberkenbosch)
